# -*- coding: utf-8 -*-
"""
URL definitions for Canvas API.
"""

from django.conf.urls import url

from integrated_channels.canvas.views import CanvasCompleteOAuthView

urlpatterns = [
    url(
        r'^oauth-complete$',
        CanvasCompleteOAuthView.as_view(),
        name='canvas-oauth-complete'
    ),
]



# Generated by Django 2.2.14 on 2020-07-02 15:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0098_auto_20200629_1756'),
    ]

    operations = [
        migrations.AlterField(
            model_name='enterprisecourseenrollment',
            name='marked_done',
            field=models.NullBooleanField(default=False, help_text='Specifies whether a user marked this course as completed in the learner portal.'),
        ),
        migrations.AlterField(
            model_name='historicalenterprisecourseenrollment',
            name='marked_done',
            field=models.NullBooleanField(default=False, help_text='Specifies whether a user marked this course as completed in the learner portal.'),
        ),
    ]



# -*- coding: utf-8 -*-


import django_countries.fields

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0052_create_unique_slugs'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomer',
            name='country',
            field=django_countries.fields.CountryField(max_length=2, null=True),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomer',
            name='country',
            field=django_countries.fields.CountryField(max_length=2, null=True),
        ),
    ]



"""
Transmitter for Canvas content metadata
"""

from integrated_channels.canvas.client import CanvasAPIClient
from integrated_channels.integrated_channel.transmitters.content_metadata import ContentMetadataTransmitter


class CanvasContentMetadataTransmitter(ContentMetadataTransmitter):
    """
    This transmitter transmits exported content metadata to Canvas.
    """

    def __init__(self, enterprise_configuration, client=CanvasAPIClient):
        """
        Use the ``CanvasAPIClient`` for content metadata transmission to Canvas.
        """
        super(CanvasContentMetadataTransmitter, self).__init__(
            enterprise_configuration=enterprise_configuration,
            client=client
        )

    def _prepare_items_for_transmission(self, channel_metadata_items):
        # here is a hack right now to send only one item
        # we have to investigate how to handle multiple
        # metadata items
        return {
            'course': channel_metadata_items[0],
        }



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-01-22 20:27


import fernet_fields.fields

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0037_auto_20180110_0450'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomerreportingconfiguration',
            name='decrypted_password',
            field=fernet_fields.fields.EncryptedCharField(blank=True, help_text='This password will be used to secure the zip file. It will be encrypted when stored in the database.', max_length=256, null=True),
        ),
        migrations.AddField(
            model_name='enterprisecustomerreportingconfiguration',
            name='decrypted_sftp_password',
            field=fernet_fields.fields.EncryptedCharField(blank=True, help_text='If the delivery method is sftp, the password to use to securely access the host. The password will be encrypted when stored in the database.', max_length=256, null=True),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.27 on 2020-03-11 08:08


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0090_update_content_filter'),
    ]

    operations = [
        migrations.AddField(
            model_name='historicalpendingenrollment',
            name='sales_force_id',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='pendingenrollment',
            name='sales_force_id',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]



"""
Views containing APIs for cornerstone integrated channel
"""

from edx_rest_framework_extensions.auth.jwt.authentication import JwtAuthentication
from rest_framework import generics, permissions, renderers, status
from rest_framework.authentication import SessionAuthentication
from rest_framework.response import Response

from enterprise.api.throttles import ServiceUserThrottle
from enterprise.utils import get_enterprise_customer, get_enterprise_worker_user, get_oauth2authentication_class
from integrated_channels.cornerstone.models import CornerstoneEnterpriseCustomerConfiguration


class CornerstoneCoursesListView(generics.ListAPIView):
    """
        **Use Cases**

            Get a list of courses to share on cornerstone filtered by an enterprise customer.

        **Example Requests**

            GET /cornerstone/course-list?ciid={customer_uuid}

        **Query Parameters for GET**

            * ciid: Filters the result to courses available in catalogs corresponding to the
              given ciid where value of ciid should be uuid of any enterprise customer.

        **Response Values**

            If the request for information about the course list is successful, an HTTP 200 "OK" response
            is returned.

            The HTTP 200 response has the following values.

            * JSON response with a list of the course objects. Each course object has these fields

                * ID: Unique Course id.

                * Title: Title of course.

                * Description: Course overview.

                * URL: URL where user is redirected to.

                * Thumbnail: Url of the course thumbnail image.

                * IsActive: Boolean value indicating if course is active and available.

                * LastModifiedUTC: Time of the last modification made.

                * Duration: Course duration.

                * Owners: List organizations that are course owners.

                * Languages: List of available languages for a course.

                * Subjects: List of subjects for course.

            If the user is not logged in, a 401 error is returned.

            If the user is not global staff, a 403 error is returned.

            If ciid parameter is not provided, a 400 error is returned.

            If the specified ciid is not valid or any of registered enterprise customers
            a 404 error is returned.

            If the specified enterprise does not have course catalog an HTTP 200 "OK" response is returned with an
            empty result.

    """
    permission_classes = (permissions.IsAuthenticated,)

    OAuth2Authentication = get_oauth2authentication_class()
    if OAuth2Authentication is not None:
        authentication_classes = (JwtAuthentication, OAuth2Authentication, SessionAuthentication,)
    else:
        authentication_classes = (JwtAuthentication, SessionAuthentication,)

    throttle_classes = (ServiceUserThrottle,)
    renderer_classes = [renderers.JSONRenderer]

    def get(self, request, *args, **kwargs):  # pylint: disable=arguments-differ
        enterprise_customer_uuid = request.GET.get('ciid')
        if not enterprise_customer_uuid:
            return Response(
                status=status.HTTP_400_BAD_REQUEST,
                data={
                    "message": (
                        u"Cornerstone course list API expects ciid parameter."
                    )
                })

        enterprise_customer = get_enterprise_customer(enterprise_customer_uuid)
        if not enterprise_customer:
            return Response(
                status=status.HTTP_404_NOT_FOUND,
                data={
                    "message": (
                        u"No enterprise data found for given ciid."
                    )
                })

        worker_user = get_enterprise_worker_user()
        enterprise_config = CornerstoneEnterpriseCustomerConfiguration.objects.get(
            enterprise_customer=enterprise_customer
        )
        exporter = enterprise_config.get_content_metadata_exporter(worker_user)
        transmitter = enterprise_config.get_content_metadata_transmitter()
        data = transmitter.transmit(exporter.export())
        return Response(data)



# -*- coding: utf-8 -*-
"""
Integrated channel custom exceptions.
"""


class ClientError(Exception):
    """
    Indicate a problem when interacting with an integrated channel.
    """


class CanvasClientError(ClientError):
    """
    Exception for specific Canvas integrated channel client problems.
    """

    def __init__(self, message):
        """Add a Canvas client identifier to the beginning of the error message."""
        super().__init__("Canvas Client Error: " + message)



# -*- coding: utf-8 -*-


import django
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0001_initial'),
        ('enterprise', '0002_enterprisecustomerbrandingconfiguration'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='enterprisecustomerbrandingconfiguration',
            options={'verbose_name': 'Branding Configuration', 'verbose_name_plural': 'Branding Configurations'},
        ),
        migrations.AddField(
            model_name='enterprisecustomer',
            name='site',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='enterprise_customers', default=1, to='sites.Site'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomer',
            name='site',
            field=models.ForeignKey(related_name='+', on_delete=django.db.models.deletion.DO_NOTHING, db_constraint=False, blank=True, to='sites.Site', null=True),
        ),
        migrations.AlterField(
            model_name='enterprisecustomerbrandingconfiguration',
            name='enterprise_customer',
            field=models.OneToOneField(related_name='branding_configuration', on_delete=django.db.models.deletion.CASCADE, to='enterprise.EnterpriseCustomer'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.2 on 2016-10-21 11:55


import uuid

import django.db.models.deletion
import django.utils.timezone
from django.conf import settings
from django.db import migrations, models

import model_utils.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='EnterpriseCustomer',
            fields=[
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('uuid', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('name', models.CharField(help_text='Enterprise Customer name.', max_length=255)),
                ('active', models.BooleanField(default=True)),
            ],
            options={
                'verbose_name': 'Enterprise Customer',
                'verbose_name_plural': 'Enterprise Customers',
            },
        ),
        migrations.CreateModel(
            name='EnterpriseCustomerUser',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('user_id', models.PositiveIntegerField()),
                ('enterprise_customer', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='enterprise.EnterpriseCustomer')),
            ],
            options={
                'verbose_name': 'Enterprise Customer User',
                'verbose_name_plural': 'Enterprise Customer Users',
            },
        ),
        migrations.CreateModel(
            name='HistoricalEnterpriseCustomer',
            fields=[
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('uuid', models.UUIDField(db_index=True, default=uuid.uuid4, editable=False)),
                ('name', models.CharField(help_text='Enterprise Customer name.', max_length=255)),
                ('active', models.BooleanField(default=True)),
                ('history_id', models.AutoField(primary_key=True, serialize=False)),
                ('history_date', models.DateTimeField()),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('history_user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ('-history_date', '-history_id'),
                'get_latest_by': 'history_date',
                'verbose_name': 'historical Enterprise Customer',
            },
        ),
        migrations.AlterUniqueTogether(
            name='enterprisecustomeruser',
            unique_together=set([('enterprise_customer', 'user_id')]),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.3 on 2016-11-21 02:41


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0005_pendingenterprisecustomeruser'),
    ]

    operations = [
        migrations.AlterField(
            model_name='pendingenterprisecustomeruser',
            name='user_email',
            field=models.EmailField(max_length=254, unique=True),
        ),
    ]
